<?php

namespace HubPublic\ValueObjects;

use HubPublic\Collections\CartItemCollection;
/**
 * Class CartContent
 *
 * @package HubPublic\ValueObjects
 */
class CartContent
{
    /**
     * Collection of cart items
     *
     * @var \HubPublic\Collections\CartItemCollection
     */
    private $cartItems;
    /**
     * Total price
     *
     * @var float
     */
    private $totalPrice;
    /**
     * CartContent constructor.
     *
     * @param \HubPublic\Collections\CartItemCollection $cartItems  Collection of cart items
     * @param float                                     $totalPrice Total price of all items in cart
     */
    public function __construct(CartItemCollection $cartItems, $totalPrice)
    {
        $this->cartItems = $cartItems;
        $this->totalPrice = $totalPrice;
    }
    /**
     * Returns a collection of all items in cart.
     *
     * @return \HubPublic\Collections\CartItemCollection Cart item collection
     */
    public function getCartItemCollection()
    {
        return $this->cartItems;
    }
    /**
     * Returns the total price of all items in cart.
     *
     * @return float Total price
     */
    public function getTotalPrice()
    {
        return $this->totalPrice;
    }
}